package Bencher::Scenarios::LoggingModules;

our $DATE = '2021-04-09'; # DATE
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: Benchmark logging modules

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::LoggingModules - Benchmark logging modules

=head1 VERSION

This document describes version 0.004 of Bencher::Scenarios::LoggingModules (from Perl distribution Bencher-Scenarios-LoggingModules), released on 2021-04-09.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::LoggingModules::NullLogging>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-LoggingModules>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-LoggingModules>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Bencher-Scenarios-LoggingModules/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
